@@ -6,7 +6,7 @@
  * Date        : 2003-10-24
  * Description : Raw converter batch dialog
  *
- * Copyright (C) 2003-2005 by Renchi Raju <renchi@pooh.tam.uiuc.edu>
+ * Copyright (C) 2003-2005 by Renchi Raju <renchi dot raju at gmail dot com>
  * Copyright (C) 2006-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
  *
  * This program is free software; you can redistribute it
@@ -21,7 +21,6 @@
  *
  * ============================================================ */
 
-#include "batchdialog.h"
 #include "batchdialog.moc"
 
 // C ANSI includes
@@ -88,6 +87,7 @@ extern "C"
 #include "savesettingswidget.h"
 
 using namespace KDcrawIface;
+using namespace KIPIPlugins;
 
 namespace KIPIRawConverterPlugin
 {
@@ -112,30 +112,30 @@ public:
         iface               = 0;
     }
 
-    bool                      busy;
-    bool                      convertBlink;
+    bool                 busy;
+    bool                 convertBlink;
 
-    QTimer                   *blinkConvertTimer;
+    QTimer*              blinkConvertTimer;
 
-    QWidget                  *page;
+    QWidget*             page;
 
-    QStringList               fileList;
+    QStringList          fileList;
 
-    QProgressBar             *progressBar;
+    QProgressBar*        progressBar;
 
-    QTreeWidget              *listView;
+    QTreeWidget*         listView;
 
-    CListViewItem            *currentConvertItem;
+    CListViewItem*       currentConvertItem;
 
-    ActionThread             *thread;
+    ActionThread*        thread;
 
-    SaveSettingsWidget       *saveSettingsBox;
+    SaveSettingsWidget*  saveSettingsBox;
 
-    DcrawSettingsWidget      *decodingSettingsBox;
+    DcrawSettingsWidget* decodingSettingsBox;
 
-    KIPIPlugins::KPAboutData *about;
+    KPAboutData*         about;
 
-    KIPI::Interface          *iface;
+    KIPI::Interface*     iface;
 };
 
 BatchDialog::BatchDialog(KIPI::Interface* iface)
@@ -144,15 +144,15 @@ BatchDialog::BatchDialog(KIPI::Interface* iface)
     d->iface = iface;
 
     setButtons(Help | Default | Apply | Close | User1 | User2);
-    setDefaultButton(KDialog::Close);
+    setDefaultButton(Close);
     setButtonToolTip(Close, i18n("Exit RAW Converter"));
     setCaption(i18n("RAW Image Batch Converter"));
     setModal(false);
-    setButtonIcon(User1, KIcon("list-add"));
-    setButtonText(User1, i18n("&Add"));
+    setButtonIcon(User1,    KIcon("list-add"));
+    setButtonText(User1,    i18n("&Add"));
     setButtonToolTip(User1, i18n("Add new RAW files to the list"));
-    setButtonIcon(User2, KIcon("list-remove"));
-    setButtonText(User2, i18n("&Remove"));
+    setButtonIcon(User2,    KIcon("list-remove"));
+    setButtonText(User2,    i18n("&Remove"));
     setButtonToolTip(User2, i18n("Remove selected RAW files from the list"));
 
     d->page = new QWidget( this );
@@ -226,7 +226,7 @@ BatchDialog::BatchDialog(KIPI::Interface* iface)
 
     d->about->addAuthor(ki18n("Renchi Raju"),
                        ki18n("Author"),
-                             "renchi at pooh dot tam dot uiuc dot edu");
+                             "renchi dot raju at gmail dot com");
 
     d->about->addAuthor(ki18n("Gilles Caulier"),
                        ki18n("Developer and maintainer"),
@@ -277,11 +277,11 @@ BatchDialog::BatchDialog(KIPI::Interface* iface)
     connect(this, SIGNAL(user2Clicked()),
             this, SLOT(slotRemoveItems()));
 
-    connect(d->thread, SIGNAL(starting(const ActionData&)),
-            this, SLOT(slotAction(const ActionData&)));
+    connect(d->thread, SIGNAL(starting(const KIPIRawConverterPlugin::ActionData&)),
+            this, SLOT(slotAction(const KIPIRawConverterPlugin::ActionData&)));
 
-    connect(d->thread, SIGNAL(finished(const ActionData&)),
-            this, SLOT(slotAction(const ActionData&)));
+    connect(d->thread, SIGNAL(finished(const KIPIRawConverterPlugin::ActionData&)),
+            this, SLOT(slotAction(const KIPIRawConverterPlugin::ActionData&)));
 
     connect(d->iface, SIGNAL(gotThumbnail( const KUrl&, const QPixmap& )),
             this, SLOT(slotThumbnail(const KUrl&, const QPixmap&)));
@@ -317,6 +317,7 @@ void BatchDialog::closeEvent(QCloseEvent *e)
     // Stop current conversion if necessary
     if (d->busy) slotStartStop();
     saveSettings();
+    d->listView->clear();
     e->accept();
 }
 
@@ -325,6 +326,7 @@ void BatchDialog::slotClose()
     // Stop current conversion if necessary
     if (d->busy) slotStartStop();
     saveSettings();
+    d->listView->clear();
     done(Close);
 }
 
@@ -371,14 +373,8 @@ void BatchDialog::readSettings()
         (KDcrawIface::RawDecodingSettings::OutputColorSpace)group.readEntry("Output Color Space",
             (int)(KDcrawIface::RawDecodingSettings::SRGB)));
 
-    d->saveSettingsBox->setFileFormat(
-        (SaveSettingsWidget::OutputFormat)group.readEntry("Output Format",
-            (int)(SaveSettingsWidget::OUTPUT_PNG)));
-
-    d->saveSettingsBox->setConflictRule(
-        (SaveSettingsWidget::ConflictRule)group.readEntry("Conflict",
-            (int)(SaveSettingsWidget::OVERWRITE)));
 
+    d->saveSettingsBox->readSettings(group);
     d->saveSettingsBox->slotPopulateImageFormat(d->decodingSettingsBox->sixteenBits());
 
     KConfigGroup group2 = config.group(QString("Batch Raw Converter Dialog"));
@@ -416,8 +412,8 @@ void BatchDialog::saveSettings()
 #if KDCRAW_VERSION >= 0x000500
     group.writeEntry("AutoBrightness", d->decodingSettingsBox->useAutoBrightness());
 #endif
-    group.writeEntry("Output Format", (int)d->saveSettingsBox->fileFormat());
-    group.writeEntry("Conflict", (int)d->saveSettingsBox->conflictRule());
+
+    d->saveSettingsBox->writeSettings(group);
 
     KConfigGroup group2 = config.group(QString("Batch Raw Converter Dialog"));
     saveDialogSize(group2);
@@ -730,7 +726,7 @@ void BatchDialog::processed(const KUrl& url, const QString& tmpFile)
                 case KIO::R_CANCEL:
                 case KIO::R_SKIP:
                 {
-                    destFile = QString();
+                    destFile.clear();
                     d->currentConvertItem->setProgressIcon(SmallIcon("dialog-cancel"));
                     break;
                 }
@@ -776,7 +772,7 @@ void BatchDialog::processingFailed(const KUrl& /*url*/)
     d->currentConvertItem = 0;
 }
 
-void BatchDialog::slotAction(const ActionData& ad)
+void BatchDialog::slotAction(const KIPIRawConverterPlugin::ActionData& ad)
 {
     QString text;
 
@@ -795,7 +791,7 @@ void BatchDialog::slotAction(const ActionData& ad)
             }
             default:
             {
-                kWarning(51000) << "KIPIRawConverterPlugin: Unknown action";
+                kWarning() << "KIPIRawConverterPlugin: Unknown action";
                 break;
             }
         }
@@ -817,7 +813,7 @@ void BatchDialog::slotAction(const ActionData& ad)
                 }
                 default:
                 {
-                    kWarning(51000) << "KIPIRawConverterPlugin: Unknown action";
+                    kWarning() << "KIPIRawConverterPlugin: Unknown action";
                     break;
                 }
             }
@@ -856,7 +852,7 @@ void BatchDialog::slotAction(const ActionData& ad)
                 }
                 default:
                 {
-                    kWarning(51000) << "KIPIRawConverterPlugin: Unknown action";
+                    kWarning() << "KIPIRawConverterPlugin: Unknown action";
                     break;
                 }
             }
