@@ -4,11 +4,11 @@
  * http://www.kipi-plugins.org
  *
  * Date        : 2005-17-06
- * Description : a kipi plugin to import/export images to/from 
-                 SmugMug web service
+ * Description : a kipi plugin to import/export images to/from
+ *                SmugMug web service
  *
  * Copyright (C) 2005-2008 by Vardhman Jain <vardhman at gmail dot com>
- * Copyright (C) 2008 by Gilles Caulier <caulier dot gilles at gmail dot com>
+ * Copyright (C) 2008-2009 by Gilles Caulier <caulier dot gilles at gmail dot com>
  * Copyright (C) 2008-2009 by Luka Renko <lure at kubuntu dot org>
  *
  * This program is free software; you can redistribute it
@@ -26,14 +26,18 @@
 #include "smugwindow.h"
 #include "smugwindow.moc"
 
-// Qt includes.
+// Qt includes
+
 #include <QFileInfo>
 #include <QSpinBox>
 #include <QCheckBox>
+#include <QProgressBar>
 #include <QGroupBox>
+#include <QCloseEvent>
 
-// KDE includes.
-#include <KDebug>
+// KDE includes
+
+#include <kdebug.h>
 #include <KConfig>
 #include <KLocale>
 #include <KMenu>
@@ -43,28 +47,27 @@
 #include <KMessageBox>
 #include <KPushButton>
 #include <KPasswordDialog>
-#include <KProgressDialog>
 #include <KToolInvocation>
 
-// LibKExiv2 includes.
+// LibKExiv2 includes
+
 #include <libkexiv2/kexiv2.h>
 
-// LibKDcraw includes.
+// LibKDcraw includes
+
 #include <libkdcraw/version.h>
 #include <libkdcraw/kdcraw.h>
 
-#if KDCRAW_VERSION < 0x000400
-#include <libkdcraw/dcrawbinary.h>
-#endif
+// LibKIPI includes
 
-// LibKIPI includes.
 #include <libkipi/interface.h>
 #include <libkipi/uploadwidget.h>
+
+// Local includes
+
 #include "imageslist.h"
 #include "kpaboutdata.h"
 #include "pluginsversion.h"
-
-// Local includes.
 #include "smugitem.h"
 #include "smugtalker.h"
 #include "smugwidget.h"
@@ -73,28 +76,28 @@
 namespace KIPISmugPlugin
 {
 
-SmugWindow::SmugWindow(KIPI::Interface* interface, const QString &tmpFolder, 
-                       bool import, QWidget *parent)
-            : KDialog(parent)
+SmugWindow::SmugWindow(KIPI::Interface* interface, const QString& tmpFolder,
+                       bool import, QWidget* /*parent*/)
+          : KDialog(0)
 {
     m_tmpPath.clear();
-    m_tmpDir                 = tmpFolder;
-    m_interface              = interface;
-    m_import                 = import;
-    m_imagesCount            = 0;
-    m_imagesTotal            = 0;
-    m_widget                 = new SmugWidget(this, interface, import);
+    m_tmpDir      = tmpFolder;
+    m_interface   = interface;
+    m_import      = import;
+    m_imagesCount = 0;
+    m_imagesTotal = 0;
+    m_widget      = new SmugWidget(this, interface, import);
 
     setMainWidget(m_widget);
     setWindowIcon(KIcon("smugmug"));
-    setButtons(Help|User1|Close);
-    setDefaultButton(Close);
+    setButtons(Help|User1|Cancel);
+    setDefaultButton(Cancel);
     setModal(false);
 
     if (import)
     {
         setWindowTitle(i18n("Import from SmugMug Web Service"));
-        setButtonGuiItem(User1, 
+        setButtonGuiItem(User1,
                          KGuiItem(i18n("Start Download"), "network-workgroup",
                                   i18n("Start download from SmugMug web service")));
         m_widget->setMinimumSize(300, 400);
@@ -102,7 +105,7 @@ SmugWindow::SmugWindow(KIPI::Interface* interface, const QString &tmpFolder,
     else
     {
         setWindowTitle(i18n("Export to SmugMug Web Service"));
-        setButtonGuiItem(User1, 
+        setButtonGuiItem(User1,
                          KGuiItem(i18n("Start Upload"), "network-workgroup",
                                   i18n("Start upload to SmugMug web service")));
         m_widget->setMinimumSize(700, 500);
@@ -112,8 +115,8 @@ SmugWindow::SmugWindow(KIPI::Interface* interface, const QString &tmpFolder,
     connect(m_widget, SIGNAL( signalUserChangeRequest(bool) ),
             this, SLOT( slotUserChangeRequest(bool)) );
 
-    connect(m_widget->m_imgList, SIGNAL( signalImageListChanged(bool) ),
-            this, SLOT( slotImageListChanged(bool)) );
+    connect(m_widget->m_imgList, SIGNAL( signalImageListChanged() ),
+            this, SLOT( slotImageListChanged()) );
 
     connect(m_widget->m_reloadAlbumsBtn, SIGNAL( clicked() ),
             this, SLOT( slotReloadAlbumsRequest()) );
@@ -121,19 +124,17 @@ SmugWindow::SmugWindow(KIPI::Interface* interface, const QString &tmpFolder,
     connect(m_widget->m_newAlbumBtn, SIGNAL( clicked() ),
             this, SLOT( slotNewAlbumRequest()) );
 
-    connect(this, SIGNAL( closeClicked() ),
-            this, SLOT( slotClose()) );
-
     connect(this, SIGNAL( user1Clicked() ),
             this, SLOT( slotStartTransfer()) );
 
     // ------------------------------------------------------------------------
+
     m_about = new KIPIPlugins::KPAboutData(ki18n("Smug Import/Export"), 0,
                       KAboutData::License_GPL,
-                      ki18n("A Kipi plugin to import/export image collection "
-                            "to/from SmugMug web service."),
+                      ki18n("A Kipi plugin to import/export image collections "
+                            "from/to the SmugMug web service."),
                       ki18n("(c) 2005-2008, Vardhman Jain\n"
-                            "(c) 2008, Gilles Caulier\n"
+                            "(c) 2008-2009, Gilles Caulier\n"
                             "(c) 2008-2009, Luka Renko"));
 
     m_about->addAuthor(ki18n("Luka Renko"), ki18n("Author and maintainer"),
@@ -153,7 +154,7 @@ SmugWindow::SmugWindow(KIPI::Interface* interface, const QString &tmpFolder,
     // ------------------------------------------------------------------------
 
     m_loginDlg  = new KPasswordDialog(this, KPasswordDialog::ShowUsernameLine);
-    m_loginDlg->setPrompt(i18n("<qt>Enter an <b>e-mail</b> and a <b>password</b> of your "
+    m_loginDlg->setPrompt(i18n("<qt>Enter the <b>email address</b> and <b>password</b> for your "
                                "<a href=\"http://www.smugmug.com\">SmugMug</a> account</qt>"));
 
     // ------------------------------------------------------------------------
@@ -206,14 +207,14 @@ SmugWindow::SmugWindow(KIPI::Interface* interface, const QString &tmpFolder,
 
     readSettings();
 
-    kDebug(51000) << "Calling Login method";
+    kDebug() << "Calling Login method";
     buttonStateChange(m_talker->loggedIn());
 
 
     if (m_import)
     {
         // if no e-mail, switch to anonymous login
-        if (m_anonymousImport || m_email.isEmpty()) 
+        if (m_anonymousImport || m_email.isEmpty())
         {
             m_anonymousImport = true;
             authenticate();
@@ -226,7 +227,7 @@ SmugWindow::SmugWindow(KIPI::Interface* interface, const QString &tmpFolder,
     {
         // export cannot login anonymously: pop-up login window`
         if (m_email.isEmpty())
-            slotUserChangeRequest(false); 
+            slotUserChangeRequest(false);
         else
             authenticate(m_email, m_password);
     }
@@ -238,16 +239,60 @@ SmugWindow::~SmugWindow()
     delete m_about;
 }
 
+void SmugWindow::slotHelp()
+{
+    KToolInvocation::invokeHelp("smug", "kipi-plugins");
+}
+
+void SmugWindow::closeEvent(QCloseEvent *e)
+{
+    if (!e) return;
+
+    if (m_talker->loggedIn())
+        m_talker->logout();
+
+    writeSettings();
+    m_widget->imagesList()->listView()->clear();
+    e->accept();
+}
+
+void SmugWindow::slotButtonClicked(int button)
+{
+    switch (button)
+    {
+        case Cancel:
+            if (m_widget->progressBar()->isHidden())
+            {
+                writeSettings();
+                m_widget->imagesList()->listView()->clear();
+                done(Close);
+            }
+            else // cancel login/transfer
+            {
+                m_talker->cancel();
+                m_transferQueue.clear();
+                m_widget->m_imgList->processed(false);
+                m_widget->progressBar()->hide();
+            }
+            break;
+        case User1:
+            slotStartTransfer();
+            break;
+        default:
+             KDialog::slotButtonClicked(button);
+    }
+}
+
+void SmugWindow::reactivate()
+{
+    m_widget->imagesList()->loadImagesFromCurrentSelection();
+    show();
+}
+
 void SmugWindow::authenticate(const QString& email, const QString& password)
 {
-    m_authProgressDlg = new KProgressDialog(this, i18n("Authentication"));
-    m_authProgressDlg->setMinimumDuration(0);
-    m_authProgressDlg->setModal(true);
-    m_authProgressDlg->setAutoReset(true);
-    m_authProgressDlg->setAutoClose(true);
-
-    connect(m_authProgressDlg, SIGNAL( cancelClicked() ),
-            this, SLOT( slotLoginCancel() ));
+    m_widget->progressBar()->show();
+    m_widget->progressBar()->setFormat("");
 
     m_talker->login(email, password);
 }
@@ -255,11 +300,11 @@ void SmugWindow::authenticate(const QString& email, const QString& password)
 void SmugWindow::readSettings()
 {
     KConfig config("kipirc");
-    KConfigGroup grp = config.group("Smug Settings");
+    KConfigGroup grp  = config.group("Smug Settings");
     m_anonymousImport = grp.readEntry("AnonymousImport", true);
-    m_email = grp.readEntry("Email");
-    m_password = grp.readEntry("Password");
-    m_currentAlbumID = grp.readEntry("Current Album", -1);
+    m_email           = grp.readEntry("Email");
+    m_password        = grp.readEntry("Password");
+    m_currentAlbumID  = grp.readEntry("Current Album", -1);
 
     if (grp.readEntry("Resize", false))
     {
@@ -293,12 +338,12 @@ void SmugWindow::writeSettings()
     KConfig config("kipirc");
     KConfigGroup grp = config.group("Smug Settings");
     grp.writeEntry("AnonymousImport", m_anonymousImport);
-    grp.writeEntry("Email", m_email);
-    grp.writeEntry("Password", m_password);
-    grp.writeEntry("Current Album", m_currentAlbumID);
-    grp.writeEntry("Resize", m_widget->m_resizeChB->isChecked());
-    grp.writeEntry("Maximum Width",  m_widget->m_dimensionSpB->value());
-    grp.writeEntry("Image Quality",  m_widget->m_imageQualitySpB->value());
+    grp.writeEntry("Email",           m_email);
+    grp.writeEntry("Password",        m_password);
+    grp.writeEntry("Current Album",   m_currentAlbumID);
+    grp.writeEntry("Resize",          m_widget->m_resizeChB->isChecked());
+    grp.writeEntry("Maximum Width",   m_widget->m_dimensionSpB->value());
+    grp.writeEntry("Image Quality",   m_widget->m_imageQualitySpB->value());
     if (m_import)
     {
         KConfigGroup dialogGroup = config.group("Smug Import Dialog");
@@ -312,38 +357,22 @@ void SmugWindow::writeSettings()
     config.sync();
 }
 
-void SmugWindow::slotHelp()
-{
-    KToolInvocation::invokeHelp("smug", "kipi-plugins");
-}
-
-void SmugWindow::slotClose()
-{
-    if (m_talker->loggedIn())
-        m_talker->logout();
-
-    writeSettings();
-
-    done(Close);
-}
-
 void SmugWindow::slotLoginProgress(int step, int maxStep, const QString &label)
 {
-    if (!m_authProgressDlg)
-        return;
+    QProgressBar* progressBar = m_widget->progressBar();
 
     if (!label.isEmpty())
-        m_authProgressDlg->setLabelText(label);
+        progressBar->setFormat(label);
 
     if (maxStep > 0)
-        m_authProgressDlg->progressBar()->setMaximum(maxStep);
+        progressBar->setMaximum(maxStep);
 
-    m_authProgressDlg->progressBar()->setValue(step);
+    progressBar->setValue(step);
 }
 
 void SmugWindow::slotLoginDone(int errCode, const QString &errMsg)
 {
-    m_authProgressDlg->hide();
+    m_widget->progressBar()->hide();
 
     buttonStateChange(m_talker->loggedIn());
     SmugUser user = m_talker->getUser();
@@ -363,8 +392,10 @@ void SmugWindow::slotLoginDone(int errCode, const QString &errMsg)
             }
         }
         else
+        {
             // get albums from current user
             m_talker->listAlbums();
+        }
     }
     else
     {
@@ -389,15 +420,13 @@ void SmugWindow::slotListAlbumsDone(int errCode, const QString &errMsg,
             albumIcon = "folder-locked";
         else if (albumsList.at(i).isPublic)
             albumIcon = "folder-image";
-        else 
+        else
             albumIcon = "folder";
 
-        m_widget->m_albumsCoB->addItem(
-            KIcon(albumIcon),
-            albumsList.at(i).title,
-            albumsList.at(i).id);
-       if (m_currentAlbumID == albumsList.at(i).id)
-           m_widget->m_albumsCoB->setCurrentIndex(i);
+        m_widget->m_albumsCoB->addItem(KIcon(albumIcon), albumsList.at(i).title, albumsList.at(i).id);
+
+        if (m_currentAlbumID == albumsList.at(i).id)
+            m_widget->m_albumsCoB->setCurrentIndex(i);
     }
 }
 
@@ -422,16 +451,9 @@ void SmugWindow::slotListPhotosDone(int errCode, const QString &errMsg,
     m_imagesTotal = m_transferQueue.count();
     m_imagesCount = 0;
 
-    m_progressDlg = new KProgressDialog(this, i18n("Transfer Progress"));
-    m_progressDlg->setMinimumDuration(0);
-    m_progressDlg->setModal(true);
-    m_progressDlg->setAutoReset(true);
-    m_progressDlg->setAutoClose(true);
-    m_progressDlg->progressBar()->setFormat(i18n("%v / %m"));
-
-    connect(m_progressDlg, SIGNAL( cancelClicked() ),
-            this, SLOT( slotTransferCancel() ));
-
+    m_widget->progressBar()->setMaximum(m_imagesTotal);
+    m_widget->progressBar()->setValue(0);
+    
     // start download with first photo in queue
     downloadNextPhoto();
 }
@@ -441,9 +463,9 @@ void SmugWindow::slotListAlbumTmplDone(int errCode, const QString &errMsg,
 {
     // always put at least default <none> subcategory
     m_albumDlg->m_templateCoB->clear();
-    m_albumDlg->m_templateCoB->addItem(i18n("<none>"), 0);
+    m_albumDlg->m_templateCoB->addItem(i18n("&lt;none&gt;"), 0);
 
-    if (errCode != 0) 
+    if (errCode != 0)
     {
         KMessageBox::error(this, i18n("SmugMug Call Failed: %1\n", errMsg));
         return;
@@ -456,18 +478,16 @@ void SmugWindow::slotListAlbumTmplDone(int errCode, const QString &errMsg,
             albumIcon = "folder-locked";
         else if (albumTList.at(i).isPublic)
             albumIcon = "folder-image";
-        else 
+        else
             albumIcon = "folder";
 
-        m_albumDlg->m_templateCoB->addItem(
-            KIcon(albumIcon),
-            albumTList.at(i).name,
-            albumTList.at(i).id);
-       if (m_currentTmplID == albumTList.at(i).id)
-           m_albumDlg->m_templateCoB->setCurrentIndex(i+1);
+        m_albumDlg->m_templateCoB->addItem(KIcon(albumIcon), albumTList.at(i).name, albumTList.at(i).id);
+
+        if (m_currentTmplID == albumTList.at(i).id)
+            m_albumDlg->m_templateCoB->setCurrentIndex(i+1);
     }
-    m_currentTmplID = m_albumDlg->m_templateCoB->itemData(
-                          m_albumDlg->m_templateCoB->currentIndex()).toInt();
+
+    m_currentTmplID = m_albumDlg->m_templateCoB->itemData(m_albumDlg->m_templateCoB->currentIndex()).toInt();
 
     // now fill in categories
     m_talker->listCategories();
@@ -476,13 +496,14 @@ void SmugWindow::slotListAlbumTmplDone(int errCode, const QString &errMsg,
 void SmugWindow::slotListCategoriesDone(int errCode, const QString &errMsg,
                                         const QList <SmugCategory>& categoriesList)
 {
-    if (errCode != 0) 
+    if (errCode != 0)
     {
         KMessageBox::error(this, i18n("SmugMug Call Failed: %1\n", errMsg));
         return;
     }
 
     m_albumDlg->m_categCoB->clear();
+
     for (int i = 0; i < categoriesList.size(); ++i)
     {
         m_albumDlg->m_categCoB->addItem(
@@ -491,6 +512,7 @@ void SmugWindow::slotListCategoriesDone(int errCode, const QString &errMsg,
        if (m_currentCategoryID == categoriesList.at(i).id)
            m_albumDlg->m_categCoB->setCurrentIndex(i);
     }
+
     m_currentCategoryID = m_albumDlg->m_categCoB->itemData(
                           m_albumDlg->m_categCoB->currentIndex()).toInt();
     m_talker->listSubCategories(m_currentCategoryID);
@@ -501,9 +523,9 @@ void SmugWindow::slotListSubCategoriesDone(int errCode, const QString &errMsg,
 {
     // always put at least default <none> subcategory
     m_albumDlg->m_subCategCoB->clear();
-    m_albumDlg->m_subCategCoB->addItem(i18n("<none>"), 0);
+    m_albumDlg->m_subCategCoB->addItem(i18n("&lt;none&gt;"), 0);
 
-    if (errCode != 0) 
+    if (errCode != 0)
     {
         KMessageBox::error(this, i18n("SmugMug Call Failed: %1\n", errMsg));
         return;
@@ -563,7 +585,7 @@ void SmugWindow::slotBusy(bool val)
 
 void SmugWindow::slotUserChangeRequest(bool anonymous)
 {
-    kDebug(51000) << "Slot Change User Request";
+    kDebug() << "Slot Change User Request";
 
     if (m_talker->loggedIn())
         m_talker->logout();
@@ -602,14 +624,14 @@ void SmugWindow::slotReloadAlbumsRequest()
 
 void SmugWindow::slotNewAlbumRequest()
 {
-    kDebug(51000) << "Slot New Album Request";
+    kDebug() << "Slot New Album Request";
 
     // get list of album templates from SmugMug to fill in dialog
     m_talker->listAlbumTmpl();
 
     if (m_albumDlg->exec() == QDialog::Accepted)
     {
-        kDebug(51000) << "Calling New Album method";
+        kDebug() << "Calling New Album method";
         m_currentTmplID = m_albumDlg->m_templateCoB->itemData(
                         m_albumDlg->m_templateCoB->currentIndex()).toInt();
         m_currentCategoryID = m_albumDlg->m_categCoB->itemData(
@@ -621,49 +643,44 @@ void SmugWindow::slotNewAlbumRequest()
     }
 }
 
-void SmugWindow::slotLoginCancel()
-{
-    m_talker->cancel();
-    m_authProgressDlg->hide();
-}
-
 void SmugWindow::slotStartTransfer()
 {
-    kDebug(51000) << "slotStartTransfer invoked";
+    kDebug() << "slotStartTransfer invoked";
 
     if (m_import)
     {
+        m_widget->progressBar()->setFormat(i18n("%v / %m"));
+        m_widget->progressBar()->setMaximum(0);
+        m_widget->progressBar()->setValue(0);
+        m_widget->progressBar()->show();
+
         // list photos of the album, then start download
         m_talker->listPhotos(m_widget->m_albumsCoB->itemData(
-                                  m_widget->m_albumsCoB->currentIndex()).toInt(),
+                             m_widget->m_albumsCoB->currentIndex()).toInt(),
                              m_widget->getAlbumPassword(),
                              m_widget->getSitePassword());
     }
     else
     {
+        m_widget->m_imgList->clearProcessedStatus();
         m_transferQueue = m_widget->m_imgList->imageUrls();
 
         if (m_transferQueue.isEmpty())
             return;
 
         m_currentAlbumID = m_widget->m_albumsCoB->itemData(
-                                    m_widget->m_albumsCoB->currentIndex()).toInt();
+                                     m_widget->m_albumsCoB->currentIndex()).toInt();
         m_imagesTotal = m_transferQueue.count();
         m_imagesCount = 0;
 
-        m_progressDlg = new KProgressDialog(this, i18n("Transfer Progress"));
-        m_progressDlg->setMinimumDuration(0);
-        m_progressDlg->setModal(true);
-        m_progressDlg->setAutoReset(true);
-        m_progressDlg->setAutoClose(true);
-        m_progressDlg->progressBar()->setFormat(i18n("%v / %m"));
+        m_widget->progressBar()->setFormat(i18n("%v / %m"));
+        m_widget->progressBar()->setMaximum(m_imagesTotal);
+        m_widget->progressBar()->setValue(0);
+        m_widget->progressBar()->show();
 
-        connect(m_progressDlg, SIGNAL( cancelClicked() ),
-                this, SLOT( slotTransferCancel() ));
-
-        kDebug(51000) << "m_currentAlbumID" << m_currentAlbumID;
+        kDebug() << "m_currentAlbumID" << m_currentAlbumID;
         uploadNextPhoto();
-        kDebug(51000) << "slotStartTransfer done";
+        kDebug() << "slotStartTransfer done";
     }
 }
 
@@ -672,29 +689,32 @@ bool SmugWindow::prepareImageForUpload(const QString& imgPath, bool isRAW)
     QImage image;
     if (isRAW)
     {
-        kDebug(51000) << "Get RAW preview " << imgPath;
+        kDebug() << "Get RAW preview " << imgPath;
         KDcrawIface::KDcraw::loadDcrawPreview(image, imgPath);
     }
     else
-        image.load(imgPath);
+    {
+       image.load(imgPath);
+    }
 
     if (image.isNull())
         return false;
 
     // get temporary file name
-    m_tmpPath = m_tmpDir + QFileInfo(imgPath).baseName().trimmed() + ".jpg";
+    m_tmpPath  = m_tmpDir + QFileInfo(imgPath).baseName().trimmed() + ".jpg";
 
     // rescale image if requested
     int maxDim = m_widget->m_dimensionSpB->value();
+
     if (m_widget->m_resizeChB->isChecked()
-        && (image.width() > maxDim || image.width() > maxDim))
+        && (image.width() > maxDim || image.height() > maxDim))
     {
-        kDebug(51000) << "Resizing to " << maxDim;
+        kDebug() << "Resizing to " << maxDim;
         image = image.scaled(maxDim, maxDim, Qt::KeepAspectRatio,
                                              Qt::SmoothTransformation);
     }
 
-    kDebug(51000) << "Saving to temp file: " << m_tmpPath;
+    kDebug() << "Saving to temp file: " << m_tmpPath;
     image.save(m_tmpPath, "JPEG", m_widget->m_imageQualitySpB->value());
 
     // copy meta data to temporary image
@@ -705,6 +725,7 @@ bool SmugWindow::prepareImageForUpload(const QString& imgPath, bool isRAW)
         exiv2Iface.setImageProgramId("Kipi-plugins", kipiplugins_version);
         exiv2Iface.save(m_tmpPath);
     }
+
     return true;
 }
 
@@ -712,25 +733,24 @@ void SmugWindow::uploadNextPhoto()
 {
     if (m_transferQueue.isEmpty())
     {
-        m_progressDlg->hide();
+        m_widget->progressBar()->hide();
         return;
     }
 
-    m_progressDlg->progressBar()->setMaximum(m_imagesTotal);
-    m_progressDlg->progressBar()->setValue(m_imagesCount);
-
+    m_widget->m_imgList->processing(m_transferQueue.first());
+    
     QString imgPath = m_transferQueue.first().path();
 
+    m_widget->progressBar()->setMaximum(m_imagesTotal);
+    m_widget->progressBar()->setValue(m_imagesCount);
+
     // check if we have to RAW file -> use preview image then
-#if KDCRAW_VERSION < 0x000400
-    QString rawFilesExt(KDcrawIface::DcrawBinary::instance()->rawFiles());
-#else
     QString rawFilesExt(KDcrawIface::KDcraw::rawFiles());
-#endif
     QFileInfo fileInfo(imgPath);
     bool isRAW = rawFilesExt.toUpper().contains(fileInfo.suffix().toUpper());
     bool res;
-    if (isRAW || m_widget->m_resizeChB->isChecked()) 
+
+    if (isRAW || m_widget->m_resizeChB->isChecked())
     {
         if (!prepareImageForUpload(imgPath, isRAW))
         {
@@ -744,43 +764,39 @@ void SmugWindow::uploadNextPhoto()
         m_tmpPath.clear();
         res = m_talker->addPhoto(imgPath, m_currentAlbumID);
     }
+
     if (!res)
     {
         slotAddPhotoDone(666, i18n("Cannot open file"));
         return;
     }
-
-    m_progressDlg->setLabelText(i18n("Uploading file %1",
-                                     m_transferQueue.first().path()));
 }
 
 void SmugWindow::slotAddPhotoDone(int errCode, const QString& errMsg)
 {
     // Remove temporary file if it was used
-    if (!m_tmpPath.isEmpty()) 
+    if (!m_tmpPath.isEmpty())
     {
         QFile::remove(m_tmpPath);
         m_tmpPath.clear();
     }
 
-    // Remove photo uploaded from the list
-    m_widget->m_imgList->removeItemByUrl(m_transferQueue.first());
-    m_transferQueue.pop_front();
+    m_widget->m_imgList->processed(errCode == 0);
 
     if (errCode == 0)
     {
+        m_transferQueue.pop_front();
         m_imagesCount++;
     }
     else
     {
-        m_imagesTotal--;
         if (KMessageBox::warningContinueCancel(this,
                          i18n("Failed to upload photo into SmugMug: %1\n"
                               "Do you want to continue?", errMsg))
                          != KMessageBox::Continue)
         {
+            m_widget->progressBar()->hide();
             m_transferQueue.clear();
-            m_progressDlg->hide();
             return;
         }
     }
@@ -792,26 +808,23 @@ void SmugWindow::downloadNextPhoto()
 {
     if (m_transferQueue.isEmpty())
     {
-        m_progressDlg->hide();
+        m_widget->progressBar()->hide();
         return;
     }
 
-    m_progressDlg->progressBar()->setMaximum(m_imagesTotal);
-    m_progressDlg->progressBar()->setValue(m_imagesCount);
+    m_widget->progressBar()->setMaximum(m_imagesTotal);
+    m_widget->progressBar()->setValue(m_imagesCount);
 
     QString imgPath = m_transferQueue.first().url();
 
     m_talker->getPhoto(imgPath);
-
-    m_progressDlg->setLabelText(i18n("Downloading file %1", imgPath));
 }
 
-void SmugWindow::slotGetPhotoDone(int errCode, const QString& errMsg, 
+void SmugWindow::slotGetPhotoDone(int errCode, const QString& errMsg,
                                   const QByteArray& photoData)
 {
-    QString imgPath = m_widget->getDestinationPath() + '/' 
+    QString imgPath = m_widget->getDestinationPath() + '/'
                       + QFileInfo(m_transferQueue.first().path()).fileName();
-    m_transferQueue.pop_front();
 
     if (errCode == 0)
     {
@@ -830,32 +843,31 @@ void SmugWindow::slotGetPhotoDone(int errCode, const QString& errMsg,
 
         if (errText.isEmpty())
         {
+            m_transferQueue.pop_front();
             m_imagesCount++;
         }
         else
         {
-            m_imagesTotal--;
             if (KMessageBox::warningContinueCancel(this,
                              i18n("Failed to save photo: %1\n"
                                   "Do you want to continue?", errText))
                              != KMessageBox::Continue)
             {
                 m_transferQueue.clear();
-                m_progressDlg->hide();
+                m_widget->progressBar()->hide();
                 return;
             }
         }
     }
     else
     {
-        m_imagesTotal--;
         if (KMessageBox::warningContinueCancel(this,
                          i18n("Failed to download photo: %1\n"
                               "Do you want to continue?", errMsg))
                          != KMessageBox::Continue)
         {
             m_transferQueue.clear();
-            m_progressDlg->hide();
+            m_widget->progressBar()->hide();
             return;
         }
     }
@@ -863,18 +875,10 @@ void SmugWindow::slotGetPhotoDone(int errCode, const QString& errMsg,
     downloadNextPhoto();
 }
 
-void SmugWindow::slotTransferCancel()
-{
-    m_transferQueue.clear();
-    m_progressDlg->hide();
-
-    m_talker->cancel();
-}
-
 void SmugWindow::slotCreateAlbumDone(int errCode, const QString& errMsg,
                                      int newAlbumID)
 {
-    if (errCode != 0) 
+    if (errCode != 0)
     {
         KMessageBox::error(this, i18n("SmugMug Call Failed: %1\n", errMsg));
         return;
@@ -885,9 +889,9 @@ void SmugWindow::slotCreateAlbumDone(int errCode, const QString& errMsg,
     m_talker->listAlbums();
 }
 
-void SmugWindow::slotImageListChanged(bool state)
+void SmugWindow::slotImageListChanged()
 {
-    enableButton(User1, !state);
+    enableButton(User1, !(m_widget->m_imgList->imageUrls().isEmpty()));
 }
 
 } // namespace KIPISmugPlugin
